@@ -221,7 +221,7 @@ byte angband_color_table[256][4] =
 /*
  * Standard sound (and message) names
  */
-const cptr angband_sound_name[SOUND_MAX] =
+const cptr angband_sound_name[MSG_MAX] =
 {
 	"",
 	"hit",
@@ -235,7 +235,7 @@ const cptr angband_sound_name[SOUND_MAX] =
 	"teleport",
 	"shoot",
 	"quaff",
-	"zap",
+	"zap_rod",
 	"walk",
 	"tpother",
 	"hitwall",
@@ -251,8 +251,128 @@ const cptr angband_sound_name[SOUND_MAX] =
 	"bell",
 	"nothing_to_open",
 	"lockpick_fail",
-	"stairs",
+	"stairs_down", 
 	"hitpoint_warn",
+	"act_artifact", 
+	"use_staff", 
+	"destroy", 
+	"mon_hit", 
+	"mon_touch", 
+	"mon_punch", 
+	"mon_kick", 
+	"mon_claw", 
+	"mon_bite", 
+	"mon_sting", 
+	"mon_butt", 
+	"mon_crush", 
+	"mon_engulf", 
+	"mon_crawl", 
+	"mon_drool", 
+	"mon_spit", 
+	"mon_gaze", 
+	"mon_wail", 
+	"mon_spore", 
+	"mon_beg", 
+	"mon_insult", 
+	"mon_moan", 
+	"recover", 
+	"blind", 
+	"confused", 
+	"poisoned", 
+	"afraid", 
+	"paralyzed", 
+	"drugged", 
+	"speed", 
+	"slow", 
+	"shield", 
+	"blessed", 
+	"hero", 
+	"berserk", 
+	"prot_evil", 
+	"invuln", 
+	"see_invis", 
+	"infrared", 
+	"res_acid", 
+	"res_elec", 
+	"res_fire", 
+	"res_cold", 
+	"res_pois", 
+	"stun", 
+	"cut", 
+	"stairs_up", 
+	"store_enter", 
+	"store_leave", 
+	"store_home", 
+	"money1", 
+	"money2", 
+	"money3", 
+	"shoot_hit", 
+	"store5", 
+	"lockpick", 
+	"disarm", 
+	"identify_bad", 
+	"identify_ego", 
+	"identify_art", 
+	"breathe_elements", 
+	"breathe_frost", 
+	"breathe_elec", 
+	"breathe_acid", 
+	"breathe_gas", 
+	"breathe_fire", 
+	"breathe_confusion", 
+	"breathe_disenchant", 
+	"breathe_chaos", 
+	"breathe_shards", 
+	"breathe_sound", 
+	"breathe_light", 
+	"breathe_dark", 
+	"breathe_nether", 
+	"breathe_nexus", 
+	"breathe_time", 
+	"breathe_inertia", 
+	"breathe_gravity", 
+	"breathe_plasma", 
+	"breathe_force", 
+	"summon_monster", 
+	"summon_angel", 
+	"summon_undead", 
+	"summon_animal", 
+	"summon_spider", 
+	"summon_hound", 
+	"summon_hydra", 
+	"summon_demon", 
+	"summon_dragon", 
+	"summon_gr_undead", 
+	"summon_gr_dragon", 
+	"summon_gr_demon", 
+	"summon_ringwraith", 
+	"summon_unique", 
+	"wield", 
+	"cursed", 
+	"pseudo_id", 
+	"hungry", 
+	"notice", 
+	"ambient_day", 
+	"ambient_nite", 
+	"ambient_dng1", 
+	"ambient_dng2", 
+	"ambient_dng3", 
+	"ambient_dng4", 
+	"ambient_dng5", 
+	"mon_create_trap", 
+	"mon_shriek", 
+	"mon_cast_fear", 
+	"hit_good", 
+	"hit_great", 
+	"hit_superb", 
+	"hit_hi_great", 
+	"hit_hi_superb", 
+	"cast_spell", 
+	"pray_prayer",
+	"kill_unique",
+	"kill_king",
+	"drain_stat",
+	"multiply",
 };
 
 
